[U-Boot] [PATCH v4] sf: probe: Add support for S25FL* flash parts

Jagannadha Sutradharudu Teki jagannadha.sutradharudu-teki at xilinx.com
Tue Sep 24 20:19:45 CEST 2013


Added S25FL* parts are which are avilable in spi_flash_probe_legacy.c.

Updated the sector_size attributes as per the flash parts.
Looks fine for with this sector_size for computing the size
of flash.

Signed-off-by: Jagannadha Sutradharudu Teki <jaganna at xilinx.com>
---
Changes for v4:
        - Update the ext_jedec detection
Changes for v3:
        - none
Changes for v2:
        - Enable CONFIG_SPI_FLASH_SPANSION

 drivers/mtd/spi/spi_flash_probe.c |   31 +-
 dump                              | 1182 +++++++++++++++++++++++++++++++++++++
 2 files changed, 1207 insertions(+), 6 deletions(-)
 create mode 100644 dump

diff --git a/dump b/dump
new file mode 100644
index 0000000..fb4ac4f
--- /dev/null
+++ b/dump
@@ -0,0 +1,1182 @@
+WARNING: line over 80 characters
+#872: FILE: drivers/mtd/spi/spi_flash_ops.c:228:
++		debug("PP: 0x%p => cmd = { 0x%02x 0x%02x%02x%02x } chunk_len = %zu\n",
+
+total: 0 errors, 1 warnings, 0 checks, 1190 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0001-sf-Divide-spi_flash-into-multiple-parts.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+total: 0 errors, 0 warnings, 0 checks, 575 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0002-sf-probe-Add-new-spi_flash_probe-support.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 21 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0003-sf-probe-Add-support-for-M25P-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 17 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0004-sf-probe-Add-support-for-EN25Q-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 17 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0005-sf-probe-Add-support-for-GD25-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 22 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0006-sf-probe-Add-support-for-MX25L-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 45 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0007-sf-probe-Add-support-for-W25-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 62 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0008-sf-probe-Add-support-for-S25FL-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 25 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0009-sf-probe-Add-support-for-SST25-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 22 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0010-sf-probe-Add-support-for-AT45DB-flash-parts.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 174 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0011-sf-probe-Give-proper-spacing-on-flash-table-params.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 316 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0012-sf-probe-Add-support-for-SST_WP.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 23 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0013-sf-probe-Add-support-to-clear-flash-BP-bits.patch has no obvious style problems and is ready for submission.
+WARNING: line over 80 characters
+#56: FILE: drivers/mtd/spi/spi_flash_probe.c:42:
++	{"AT45DB011D",	   0x1f2200, 0x0,	64 * 1024,     4,	       SECT_4K},
+
+WARNING: line over 80 characters
+#57: FILE: drivers/mtd/spi/spi_flash_probe.c:43:
++	{"AT45DB021D",	   0x1f2300, 0x0,	64 * 1024,     8,	       SECT_4K},
+
+WARNING: line over 80 characters
+#58: FILE: drivers/mtd/spi/spi_flash_probe.c:44:
++	{"AT45DB041D",	   0x1f2400, 0x0,	64 * 1024,     8,	       SECT_4K},
+
+WARNING: line over 80 characters
+#59: FILE: drivers/mtd/spi/spi_flash_probe.c:45:
++	{"AT45DB081D",	   0x1f2500, 0x0,	64 * 1024,    16,	       SECT_4K},
+
+WARNING: line over 80 characters
+#60: FILE: drivers/mtd/spi/spi_flash_probe.c:46:
++	{"AT45DB161D",	   0x1f2600, 0x0,	64 * 1024,    32,	       SECT_4K},
+
+WARNING: line over 80 characters
+#61: FILE: drivers/mtd/spi/spi_flash_probe.c:47:
++	{"AT45DB321D",	   0x1f2700, 0x0,	64 * 1024,    64,	       SECT_4K},
+
+WARNING: line over 80 characters
+#62: FILE: drivers/mtd/spi/spi_flash_probe.c:48:
++	{"AT45DB641D",	   0x1f2800, 0x0,	64 * 1024,   128,	       SECT_4K},
+
+WARNING: line over 80 characters
+#67: FILE: drivers/mtd/spi/spi_flash_probe.c:51:
++	{"EN25Q32B",	   0x1c3016, 0x0,	64 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#68: FILE: drivers/mtd/spi/spi_flash_probe.c:52:
++	{"EN25Q128B",	   0x1c3018, 0x0,       64 * 1024,   256,	             0},
+
+WARNING: line over 80 characters
+#73: FILE: drivers/mtd/spi/spi_flash_probe.c:55:
++	{"GD25Q64B",	   0xc84017, 0x0,	64 * 1024,   128,	       SECT_4K},
+
+WARNING: line over 80 characters
+#74: FILE: drivers/mtd/spi/spi_flash_probe.c:56:
++	{"GD25LQ32",	   0xc86016, 0x0,	64 * 1024,    64,	       SECT_4K},
+
+WARNING: line over 80 characters
+#84: FILE: drivers/mtd/spi/spi_flash_probe.c:59:
++	{"MX25L4005",	   0xc22013, 0x0,	64 * 1024,     8,	             0},
+
+WARNING: line over 80 characters
+#85: FILE: drivers/mtd/spi/spi_flash_probe.c:60:
++	{"MX25L8005",	   0xc22014, 0x0,	64 * 1024,    16,	             0},
+
+WARNING: line over 80 characters
+#86: FILE: drivers/mtd/spi/spi_flash_probe.c:61:
++	{"MX25L1605D",	   0xc22015, 0x0,	64 * 1024,    32,	             0},
+
+WARNING: line over 80 characters
+#87: FILE: drivers/mtd/spi/spi_flash_probe.c:62:
++	{"MX25L3205D",	   0xc22016, 0x0,	64 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#88: FILE: drivers/mtd/spi/spi_flash_probe.c:63:
++	{"MX25L6405D",	   0xc22017, 0x0,	64 * 1024,   128,	             0},
+
+WARNING: line over 80 characters
+#89: FILE: drivers/mtd/spi/spi_flash_probe.c:64:
++	{"MX25L12805",	   0xc22018, 0x0,	64 * 1024,   256,	             0},
+
+WARNING: line over 80 characters
+#90: FILE: drivers/mtd/spi/spi_flash_probe.c:65:
++	{"MX25L12855E",	   0xc22618, 0x0,	64 * 1024,   256,	             0},
+
+WARNING: line over 80 characters
+#104: FILE: drivers/mtd/spi/spi_flash_probe.c:68:
++	{"S25FL008A",	   0x010213, 0x0,	64 * 1024,    16,	             0},
+
+WARNING: line over 80 characters
+#105: FILE: drivers/mtd/spi/spi_flash_probe.c:69:
++	{"S25FL016A",	   0x010214, 0x0,	64 * 1024,    32,	             0},
+
+WARNING: line over 80 characters
+#106: FILE: drivers/mtd/spi/spi_flash_probe.c:70:
++	{"S25FL032A",	   0x010215, 0x0,	64 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#107: FILE: drivers/mtd/spi/spi_flash_probe.c:71:
++	{"S25FL064A",	   0x010216, 0x0,	64 * 1024,   128,	             0},
+
+WARNING: line over 80 characters
+#108: FILE: drivers/mtd/spi/spi_flash_probe.c:72:
++	{"S25FL128P_256K", 0x012018, 0x0300,   256 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#109: FILE: drivers/mtd/spi/spi_flash_probe.c:73:
++	{"S25FL128P_64K",  0x012018, 0x0301,    64 * 1024,   256,	             0},
+
+WARNING: line over 80 characters
+#110: FILE: drivers/mtd/spi/spi_flash_probe.c:74:
++	{"S25FL032P",	   0x010215, 0x4d00,    64 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#111: FILE: drivers/mtd/spi/spi_flash_probe.c:75:
++	{"S25FL064P",	   0x010216, 0x4d00,    64 * 1024,   128,	             0},
+
+WARNING: line over 80 characters
+#112: FILE: drivers/mtd/spi/spi_flash_probe.c:76:
++	{"S25FL128S_64K",  0x012018, 0x4d01,    64 * 1024,   256,		     0},
+
+WARNING: line over 80 characters
+#113: FILE: drivers/mtd/spi/spi_flash_probe.c:77:
++	{"S25FL256S_64K",  0x010219, 0x4d01,    64 * 1024,   512,	             0},
+
+WARNING: line over 80 characters
+#114: FILE: drivers/mtd/spi/spi_flash_probe.c:78:
++	{"S25FL512S_64K",  0x010220, 0x4d01,    64 * 1024,  1024,	             0},
+
+WARNING: line over 80 characters
+#137: FILE: drivers/mtd/spi/spi_flash_probe.c:81:
++	{"M25P10",	   0x202011, 0x0,       32 * 1024,     4,	             0},
+
+WARNING: line over 80 characters
+#138: FILE: drivers/mtd/spi/spi_flash_probe.c:82:
++	{"M25P20",	   0x202012, 0x0,       64 * 1024,     4,	             0},
+
+WARNING: line over 80 characters
+#139: FILE: drivers/mtd/spi/spi_flash_probe.c:83:
++	{"M25P40",	   0x202013, 0x0,       64 * 1024,     8,	             0},
+
+WARNING: line over 80 characters
+#140: FILE: drivers/mtd/spi/spi_flash_probe.c:84:
++	{"M25P80",	   0x202014, 0x0,       64 * 1024,    16,	             0},
+
+WARNING: line over 80 characters
+#141: FILE: drivers/mtd/spi/spi_flash_probe.c:85:
++	{"M25P16",	   0x202015, 0x0,       64 * 1024,    32,	             0},
+
+WARNING: line over 80 characters
+#142: FILE: drivers/mtd/spi/spi_flash_probe.c:86:
++	{"M25P32",	   0x202016, 0x0,       64 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#143: FILE: drivers/mtd/spi/spi_flash_probe.c:87:
++	{"M25P64",	   0x202017, 0x0,       64 * 1024,   128,	             0},
+
+WARNING: line over 80 characters
+#144: FILE: drivers/mtd/spi/spi_flash_probe.c:88:
++	{"M25P128",	   0x202018, 0x0,      256 * 1024,    64,	             0},
+
+WARNING: line over 80 characters
+#145: FILE: drivers/mtd/spi/spi_flash_probe.c:89:
++	{"N25Q32",	   0x20ba16, 0x0,       64 * 1024,    64,	       SECT_4K},
+
+WARNING: line over 80 characters
+#146: FILE: drivers/mtd/spi/spi_flash_probe.c:90:
++	{"N25Q32A",	   0x20bb16, 0x0,       64 * 1024,    64,	       SECT_4K},
+
+WARNING: line over 80 characters
+#147: FILE: drivers/mtd/spi/spi_flash_probe.c:91:
++	{"N25Q64",	   0x20ba17, 0x0,       64 * 1024,   128,	       SECT_4K},
+
+WARNING: line over 80 characters
+#148: FILE: drivers/mtd/spi/spi_flash_probe.c:92:
++	{"N25Q64A",	   0x20bb17, 0x0,       64 * 1024,   128,	       SECT_4K},
+
+WARNING: line over 80 characters
+#149: FILE: drivers/mtd/spi/spi_flash_probe.c:93:
++	{"N25Q128",	   0x20ba18, 0x0,       64 * 1024,   256,	       SECT_4K},
+
+WARNING: line over 80 characters
+#150: FILE: drivers/mtd/spi/spi_flash_probe.c:94:
++	{"N25Q128A",	   0x20bb18, 0x0,       64 * 1024,   256,	       SECT_4K},
+
+WARNING: line over 80 characters
+#151: FILE: drivers/mtd/spi/spi_flash_probe.c:95:
++	{"N25Q256",	   0x20ba19, 0x0,       64 * 1024,   512,	       SECT_4K},
+
+WARNING: line over 80 characters
+#152: FILE: drivers/mtd/spi/spi_flash_probe.c:96:
++	{"N25Q256A",	   0x20bb19, 0x0,       64 * 1024,   512,	       SECT_4K},
+
+WARNING: line over 80 characters
+#153: FILE: drivers/mtd/spi/spi_flash_probe.c:97:
++	{"N25Q512",	   0x20ba20, 0x0,       64 * 1024,  1024,	       SECT_4K},
+
+WARNING: line over 80 characters
+#154: FILE: drivers/mtd/spi/spi_flash_probe.c:98:
++	{"N25Q512A",	   0x20bb20, 0x0,       64 * 1024,  1024,	       SECT_4K},
+
+WARNING: line over 80 characters
+#155: FILE: drivers/mtd/spi/spi_flash_probe.c:99:
++	{"N25Q1024",	   0x20ba21, 0x0,       64 * 1024,  2048,	       SECT_4K},
+
+WARNING: line over 80 characters
+#156: FILE: drivers/mtd/spi/spi_flash_probe.c:100:
++	{"N25Q1024A",	   0x20bb21, 0x0,       64 * 1024,  2048,	       SECT_4K},
+
+WARNING: line over 80 characters
+#169: FILE: drivers/mtd/spi/spi_flash_probe.c:103:
++	{"SST25VF040B",	   0xbf258d, 0x0,	64 * 1024,     8,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#170: FILE: drivers/mtd/spi/spi_flash_probe.c:104:
++	{"SST25VF080B",	   0xbf258e, 0x0,	64 * 1024,    16,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#171: FILE: drivers/mtd/spi/spi_flash_probe.c:105:
++	{"SST25VF016B",	   0xbf2541, 0x0,	64 * 1024,    32,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#172: FILE: drivers/mtd/spi/spi_flash_probe.c:106:
++	{"SST25VF032B",	   0xbf254a, 0x0,	64 * 1024,    64,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#173: FILE: drivers/mtd/spi/spi_flash_probe.c:107:
++	{"SST25VF064C",	   0xbf254b, 0x0,	64 * 1024,   128,	       SECT_4K},
+
+WARNING: line over 80 characters
+#174: FILE: drivers/mtd/spi/spi_flash_probe.c:108:
++	{"SST25WF512",	   0xbf2501, 0x0,	64 * 1024,     1,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#175: FILE: drivers/mtd/spi/spi_flash_probe.c:109:
++	{"SST25WF010",	   0xbf2502, 0x0,	64 * 1024,     2,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#176: FILE: drivers/mtd/spi/spi_flash_probe.c:110:
++	{"SST25WF020",	   0xbf2503, 0x0,	64 * 1024,     4,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#177: FILE: drivers/mtd/spi/spi_flash_probe.c:111:
++	{"SST25WF040",	   0xbf2504, 0x0,	64 * 1024,     8,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#178: FILE: drivers/mtd/spi/spi_flash_probe.c:112:
++	{"SST25WF080",	   0xbf2505, 0x0,	64 * 1024,    16,     SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#199: FILE: drivers/mtd/spi/spi_flash_probe.c:115:
++	{"W25P80",	   0xef2014, 0x0,	64 * 1024,    16,		     0},
+
+WARNING: line over 80 characters
+#200: FILE: drivers/mtd/spi/spi_flash_probe.c:116:
++	{"W25P16",	   0xef2015, 0x0,	64 * 1024,    32,		     0},
+
+WARNING: line over 80 characters
+#201: FILE: drivers/mtd/spi/spi_flash_probe.c:117:
++	{"W25P32",	   0xef2016, 0x0,	64 * 1024,    64,		     0},
+
+WARNING: line over 80 characters
+#202: FILE: drivers/mtd/spi/spi_flash_probe.c:118:
++	{"W25X40",	   0xef3013, 0x0,	 4 * 1024,   128,	       SECT_4K},
+
+WARNING: line over 80 characters
+#203: FILE: drivers/mtd/spi/spi_flash_probe.c:119:
++	{"W25X16",	   0xef3015, 0x0,	 4 * 1024,   512,	       SECT_4K},
+
+WARNING: line over 80 characters
+#204: FILE: drivers/mtd/spi/spi_flash_probe.c:120:
++	{"W25X32",	   0xef3016, 0x0,	 4 * 1024,  1024,	       SECT_4K},
+
+WARNING: line over 80 characters
+#205: FILE: drivers/mtd/spi/spi_flash_probe.c:121:
++	{"W25X64",	   0xef3017, 0x0,	 4 * 1024,  2048,	       SECT_4K},
+
+WARNING: line over 80 characters
+#206: FILE: drivers/mtd/spi/spi_flash_probe.c:122:
++	{"W25Q80BL",	   0xef4014, 0x0,	 4 * 1024,   256,	       SECT_4K},
+
+WARNING: line over 80 characters
+#207: FILE: drivers/mtd/spi/spi_flash_probe.c:123:
++	{"W25Q16CL",	   0xef4015, 0x0,	 4 * 1024,   512,	       SECT_4K},
+
+WARNING: line over 80 characters
+#208: FILE: drivers/mtd/spi/spi_flash_probe.c:124:
++	{"W25Q32BV",	   0xef4016, 0x0,	 4 * 1024,  1024,	       SECT_4K},
+
+WARNING: line over 80 characters
+#209: FILE: drivers/mtd/spi/spi_flash_probe.c:125:
++	{"W25Q64CV",	   0xef4017, 0x0,	 4 * 1024,  2048,	       SECT_4K},
+
+WARNING: line over 80 characters
+#210: FILE: drivers/mtd/spi/spi_flash_probe.c:126:
++	{"W25Q128BV",	   0xef4018, 0x0,	 4 * 1024,  4096,	       SECT_4K},
+
+WARNING: line over 80 characters
+#211: FILE: drivers/mtd/spi/spi_flash_probe.c:127:
++	{"W25Q256",	   0xef4019, 0x0,	 4 * 1024,  8192,	       SECT_4K},
+
+WARNING: line over 80 characters
+#212: FILE: drivers/mtd/spi/spi_flash_probe.c:128:
++	{"W25Q80BW",	   0xef5014, 0x0,	 4 * 1024,   256,	       SECT_4K},
+
+WARNING: line over 80 characters
+#213: FILE: drivers/mtd/spi/spi_flash_probe.c:129:
++	{"W25Q16DW",	   0xef6015, 0x0,	 4 * 1024,   512,	       SECT_4K},
+
+WARNING: line over 80 characters
+#214: FILE: drivers/mtd/spi/spi_flash_probe.c:130:
++	{"W25Q32DW",	   0xef6016, 0x0,	 4 * 1024,  1024,	       SECT_4K},
+
+WARNING: line over 80 characters
+#215: FILE: drivers/mtd/spi/spi_flash_probe.c:131:
++	{"W25Q64DW",	   0xef6017, 0x0,	 4 * 1024,  2048,	       SECT_4K},
+
+WARNING: line over 80 characters
+#216: FILE: drivers/mtd/spi/spi_flash_probe.c:132:
++	{"W25Q128FW",	   0xef6018, 0x0,	 4 * 1024,  4096,	       SECT_4K},
+
+total: 0 errors, 77 warnings, 0 checks, 240 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0014-sf-probe-Add-support-for-erase-sector-selection-flag.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+WARNING: line over 80 characters
+#28: FILE: drivers/mtd/spi/spi_flash_probe.c:97:
++	{"N25Q512",	   0x20ba20, 0x0,       64 * 1024,  1024,      E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#29: FILE: drivers/mtd/spi/spi_flash_probe.c:98:
++	{"N25Q512A",	   0x20bb20, 0x0,       64 * 1024,  1024,      E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#30: FILE: drivers/mtd/spi/spi_flash_probe.c:99:
++	{"N25Q1024",	   0x20ba21, 0x0,       64 * 1024,  2048,      E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#31: FILE: drivers/mtd/spi/spi_flash_probe.c:100:
++	{"N25Q1024A",	   0x20bb21, 0x0,       64 * 1024,  2048,      E_FSR | SECT_4K},
+
+total: 0 errors, 4 warnings, 0 checks, 39 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0015-sf-probe-Add-support-for-flag-status-polling.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+total: 0 errors, 0 warnings, 0 checks, 75 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0016-sf-probe-Move-BAR-config-to-spi_flash_validate_ids.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 74 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0017-sf-Add-proper-comment-style-on-spi_flash-structure.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 166 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0018-sf-ramtron-Add-support-for-separate-flash-driver.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 17 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0019-sf-Remove-unneeded-flash-drivers-files.patch has no obvious style problems and is ready for submission.
+WARNING: line over 80 characters
+#21: FILE: drivers/mtd/spi/spi_flash_probe.c:52:
++	{"EN25Q64",	   0x1c3017, 0x0,	64 * 1024,   128,	       SECT_4K},
+
+total: 0 errors, 1 warnings, 0 checks, 7 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0020-sf-probe-Add-support-for-EN25Q64.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+WARNING: line over 80 characters
+#21: FILE: drivers/mtd/spi/spi_flash_probe.c:78:
++	{"S25FL256S_256K", 0x010219, 0x4d00,    64 * 1024,   512,	             0},
+
+total: 0 errors, 1 warnings, 0 checks, 15 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0021-sf-probe-Add-support-for-S25FL256S_256K.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+WARNING: line over 80 characters
+#21: FILE: drivers/mtd/spi/spi_flash_probe.c:80:
++	{"S25FL512S_256K", 0x010220, 0x4d00,    64 * 1024,  1024,	             0},
+
+total: 0 errors, 1 warnings, 0 checks, 7 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0022-sf-probe-Add-support-for-S25FL512S_256K.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+total: 0 errors, 0 warnings, 0 checks, 8 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0023-sf-probe-Use-print_size-arg-as-page_size.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 9 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0024-sf-probe-Print-erase_size-while-printing-flash-detai.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 91 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0025-sf-probe-Simply-the-BAR-configuration-logic.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 19 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0026-sf-ops-Add-static-qualifier-to-spi_flash_cmd_bankadd.patch has no obvious style problems and is ready for submission.
+WARNING: line over 80 characters
+#21: FILE: drivers/mtd/spi/spi_flash_probe.c:66:
++	{"MX25L25635F",	   0xc22019, 0x0,	64 * 1024,   512,	             0},
+
+total: 0 errors, 1 warnings, 0 checks, 7 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0027-sf-probe-Add-support-for-MX25L25635F.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+WARNING: line over 80 characters
+#21: FILE: drivers/mtd/spi/spi_flash_probe.c:67:
++	{"MX25L51235F",	   0xc2201A, 0x0,	64 * 1024,  1024,	             0},
+
+total: 0 errors, 1 warnings, 0 checks, 7 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0028-sf-probe-Add-support-for-MX25L51235F.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+total: 0 errors, 0 warnings, 0 checks, 44 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0029-sf-Remove-spi_flash_do_alloc-references.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 27 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0030-doc-SPI-Add-status.txt-for-tracking-SPI-subsys-statu.patch has no obvious style problems and is ready for submission.
+WARNING: line over 80 characters
+#97: FILE: drivers/mtd/spi/spi_flash_probe.c:51:
++	{"AT45DB011D",	   0x1f2200, 0x0,	64 * 1024,     4,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#98: FILE: drivers/mtd/spi/spi_flash_probe.c:52:
++	{"AT45DB021D",	   0x1f2300, 0x0,	64 * 1024,     8,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#99: FILE: drivers/mtd/spi/spi_flash_probe.c:53:
++	{"AT45DB041D",	   0x1f2400, 0x0,	64 * 1024,     8,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#100: FILE: drivers/mtd/spi/spi_flash_probe.c:54:
++	{"AT45DB081D",	   0x1f2500, 0x0,	64 * 1024,    16,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#101: FILE: drivers/mtd/spi/spi_flash_probe.c:55:
++	{"AT45DB161D",	   0x1f2600, 0x0,	64 * 1024,    32,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#102: FILE: drivers/mtd/spi/spi_flash_probe.c:56:
++	{"AT45DB321D",	   0x1f2700, 0x0,	64 * 1024,    64,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#103: FILE: drivers/mtd/spi/spi_flash_probe.c:57:
++	{"AT45DB641D",	   0x1f2800, 0x0,	64 * 1024,   128,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#109: FILE: drivers/mtd/spi/spi_flash_probe.c:60:
++	{"EN25Q32B",	   0x1c3016, 0x0,	64 * 1024,    64,	    0,		      0},
+
+WARNING: line over 80 characters
+#110: FILE: drivers/mtd/spi/spi_flash_probe.c:61:
++	{"EN25Q64",	   0x1c3017, 0x0,	64 * 1024,   128,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#111: FILE: drivers/mtd/spi/spi_flash_probe.c:62:
++	{"EN25Q128B",	   0x1c3018, 0x0,       64 * 1024,   256,	    0,		      0},
+
+WARNING: line over 80 characters
+#116: FILE: drivers/mtd/spi/spi_flash_probe.c:65:
++	{"GD25Q64B",	   0xc84017, 0x0,	64 * 1024,   128,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#117: FILE: drivers/mtd/spi/spi_flash_probe.c:66:
++	{"GD25LQ32",	   0xc86016, 0x0,	64 * 1024,    64,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#129: FILE: drivers/mtd/spi/spi_flash_probe.c:69:
++	{"MX25L4005",	   0xc22013, 0x0,	64 * 1024,     8,	    0,		      0},
+
+WARNING: line over 80 characters
+#130: FILE: drivers/mtd/spi/spi_flash_probe.c:70:
++	{"MX25L8005",	   0xc22014, 0x0,	64 * 1024,    16,	    0,		      0},
+
+WARNING: line over 80 characters
+#131: FILE: drivers/mtd/spi/spi_flash_probe.c:71:
++	{"MX25L1605D",	   0xc22015, 0x0,	64 * 1024,    32,	    0,		      0},
+
+WARNING: line over 80 characters
+#132: FILE: drivers/mtd/spi/spi_flash_probe.c:72:
++	{"MX25L3205D",	   0xc22016, 0x0,	64 * 1024,    64,	    0,		      0},
+
+WARNING: line over 80 characters
+#133: FILE: drivers/mtd/spi/spi_flash_probe.c:73:
++	{"MX25L6405D",	   0xc22017, 0x0,	64 * 1024,   128,	    0,		      0},
+
+WARNING: line over 80 characters
+#134: FILE: drivers/mtd/spi/spi_flash_probe.c:74:
++	{"MX25L12805",	   0xc22018, 0x0,	64 * 1024,   256,	    0,		      0},
+
+WARNING: line over 80 characters
+#135: FILE: drivers/mtd/spi/spi_flash_probe.c:75:
++	{"MX25L12855E",	   0xc22618, 0x0,	64 * 1024,   256,	    0,		      0},
+
+WARNING: line over 80 characters
+#151: FILE: drivers/mtd/spi/spi_flash_probe.c:78:
++	{"S25FL008A",	   0x010213, 0x0,	64 * 1024,    16,	    0,		      0},
+
+WARNING: line over 80 characters
+#152: FILE: drivers/mtd/spi/spi_flash_probe.c:79:
++	{"S25FL016A",	   0x010214, 0x0,	64 * 1024,    32,	    0,		      0},
+
+WARNING: line over 80 characters
+#153: FILE: drivers/mtd/spi/spi_flash_probe.c:80:
++	{"S25FL032A",	   0x010215, 0x0,	64 * 1024,    64,	    0,		      0},
+
+WARNING: line over 80 characters
+#154: FILE: drivers/mtd/spi/spi_flash_probe.c:81:
++	{"S25FL064A",	   0x010216, 0x0,	64 * 1024,   128,	    0,		      0},
+
+WARNING: line over 80 characters
+#155: FILE: drivers/mtd/spi/spi_flash_probe.c:82:
++	{"S25FL128P_256K", 0x012018, 0x0300,   256 * 1024,    64, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#156: FILE: drivers/mtd/spi/spi_flash_probe.c:83:
++	{"S25FL128P_64K",  0x012018, 0x0301,    64 * 1024,   256, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#157: FILE: drivers/mtd/spi/spi_flash_probe.c:84:
++	{"S25FL032P",	   0x010215, 0x4d00,    64 * 1024,    64, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#158: FILE: drivers/mtd/spi/spi_flash_probe.c:85:
++	{"S25FL064P",	   0x010216, 0x4d00,    64 * 1024,   128, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#159: FILE: drivers/mtd/spi/spi_flash_probe.c:86:
++	{"S25FL128S_64K",  0x012018, 0x4d01,    64 * 1024,   256, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#160: FILE: drivers/mtd/spi/spi_flash_probe.c:87:
++	{"S25FL256S_64K",  0x010219, 0x4d01,    64 * 1024,   512, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#161: FILE: drivers/mtd/spi/spi_flash_probe.c:88:
++	{"S25FL512S_64K",  0x010220, 0x4d01,    64 * 1024,  1024, RD_CMD_FULL,		      0},
+
+WARNING: line over 80 characters
+#184: FILE: drivers/mtd/spi/spi_flash_probe.c:91:
++	{"M25P10",	   0x202011, 0x0,       32 * 1024,     4,	    0,		      0},
+
+WARNING: line over 80 characters
+#185: FILE: drivers/mtd/spi/spi_flash_probe.c:92:
++	{"M25P20",	   0x202012, 0x0,       64 * 1024,     4,	    0,		      0},
+
+WARNING: line over 80 characters
+#186: FILE: drivers/mtd/spi/spi_flash_probe.c:93:
++	{"M25P40",	   0x202013, 0x0,       64 * 1024,     8,	    0,		      0},
+
+WARNING: line over 80 characters
+#187: FILE: drivers/mtd/spi/spi_flash_probe.c:94:
++	{"M25P80",	   0x202014, 0x0,       64 * 1024,    16,	    0,		      0},
+
+WARNING: line over 80 characters
+#188: FILE: drivers/mtd/spi/spi_flash_probe.c:95:
++	{"M25P16",	   0x202015, 0x0,       64 * 1024,    32,	    0,		      0},
+
+WARNING: line over 80 characters
+#189: FILE: drivers/mtd/spi/spi_flash_probe.c:96:
++	{"M25P32",	   0x202016, 0x0,       64 * 1024,    64,	    0,		      0},
+
+WARNING: line over 80 characters
+#190: FILE: drivers/mtd/spi/spi_flash_probe.c:97:
++	{"M25P64",	   0x202017, 0x0,       64 * 1024,   128,	    0,		      0},
+
+WARNING: line over 80 characters
+#191: FILE: drivers/mtd/spi/spi_flash_probe.c:98:
++	{"M25P128",	   0x202018, 0x0,      256 * 1024,    64,	    0,		      0},
+
+WARNING: line over 80 characters
+#192: FILE: drivers/mtd/spi/spi_flash_probe.c:99:
++	{"N25Q32",	   0x20ba16, 0x0,       64 * 1024,    64, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#193: FILE: drivers/mtd/spi/spi_flash_probe.c:100:
++	{"N25Q32A",	   0x20bb16, 0x0,       64 * 1024,    64, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#194: FILE: drivers/mtd/spi/spi_flash_probe.c:101:
++	{"N25Q64",	   0x20ba17, 0x0,       64 * 1024,   128, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#195: FILE: drivers/mtd/spi/spi_flash_probe.c:102:
++	{"N25Q64A",	   0x20bb17, 0x0,       64 * 1024,   128, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#196: FILE: drivers/mtd/spi/spi_flash_probe.c:103:
++	{"N25Q128",	   0x20ba18, 0x0,       64 * 1024,   256, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#197: FILE: drivers/mtd/spi/spi_flash_probe.c:104:
++	{"N25Q128A",	   0x20bb18, 0x0,       64 * 1024,   256, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#198: FILE: drivers/mtd/spi/spi_flash_probe.c:105:
++	{"N25Q256",	   0x20ba19, 0x0,       64 * 1024,   512, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#199: FILE: drivers/mtd/spi/spi_flash_probe.c:106:
++	{"N25Q256A",	   0x20bb19, 0x0,       64 * 1024,   512, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#200: FILE: drivers/mtd/spi/spi_flash_probe.c:107:
++	{"N25Q512",	   0x20ba20, 0x0,       64 * 1024,  1024, RD_CMD_FULL,	E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#201: FILE: drivers/mtd/spi/spi_flash_probe.c:108:
++	{"N25Q512A",	   0x20bb20, 0x0,       64 * 1024,  1024, RD_CMD_FULL,	E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#202: FILE: drivers/mtd/spi/spi_flash_probe.c:109:
++	{"N25Q1024",	   0x20ba21, 0x0,       64 * 1024,  2048, RD_CMD_FULL,	E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#203: FILE: drivers/mtd/spi/spi_flash_probe.c:110:
++	{"N25Q1024A",	   0x20bb21, 0x0,       64 * 1024,  2048, RD_CMD_FULL,	E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#216: FILE: drivers/mtd/spi/spi_flash_probe.c:113:
++	{"SST25VF040B",	   0xbf258d, 0x0,	64 * 1024,     8,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#217: FILE: drivers/mtd/spi/spi_flash_probe.c:114:
++	{"SST25VF080B",	   0xbf258e, 0x0,	64 * 1024,    16,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#218: FILE: drivers/mtd/spi/spi_flash_probe.c:115:
++	{"SST25VF016B",	   0xbf2541, 0x0,	64 * 1024,    32,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#219: FILE: drivers/mtd/spi/spi_flash_probe.c:116:
++	{"SST25VF032B",	   0xbf254a, 0x0,	64 * 1024,    64,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#220: FILE: drivers/mtd/spi/spi_flash_probe.c:117:
++	{"SST25VF064C",	   0xbf254b, 0x0,	64 * 1024,   128,	    0		SECT_4K},
+
+WARNING: line over 80 characters
+#221: FILE: drivers/mtd/spi/spi_flash_probe.c:118:
++	{"SST25WF512",	   0xbf2501, 0x0,	64 * 1024,     1,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#222: FILE: drivers/mtd/spi/spi_flash_probe.c:119:
++	{"SST25WF010",	   0xbf2502, 0x0,	64 * 1024,     2,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#223: FILE: drivers/mtd/spi/spi_flash_probe.c:120:
++	{"SST25WF020",	   0xbf2503, 0x0,	64 * 1024,     4,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#224: FILE: drivers/mtd/spi/spi_flash_probe.c:121:
++	{"SST25WF040",	   0xbf2504, 0x0,	64 * 1024,     8,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#225: FILE: drivers/mtd/spi/spi_flash_probe.c:122:
++	{"SST25WF080",	   0xbf2505, 0x0,	64 * 1024,    16,	    0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#246: FILE: drivers/mtd/spi/spi_flash_probe.c:125:
++	{"W25P80",	   0xef2014, 0x0,	64 * 1024,    16,	    0,		      0},
+
+WARNING: line over 80 characters
+#247: FILE: drivers/mtd/spi/spi_flash_probe.c:126:
++	{"W25P16",	   0xef2015, 0x0,	64 * 1024,    32,	    0,		      0},
+
+WARNING: line over 80 characters
+#248: FILE: drivers/mtd/spi/spi_flash_probe.c:127:
++	{"W25P32",	   0xef2016, 0x0,	64 * 1024,    64,	    0,		      0},
+
+WARNING: line over 80 characters
+#249: FILE: drivers/mtd/spi/spi_flash_probe.c:128:
++	{"W25X40",	   0xef3013, 0x0,	 4 * 1024,   128,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#250: FILE: drivers/mtd/spi/spi_flash_probe.c:129:
++	{"W25X16",	   0xef3015, 0x0,	 4 * 1024,   512,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#251: FILE: drivers/mtd/spi/spi_flash_probe.c:130:
++	{"W25X32",	   0xef3016, 0x0,	 4 * 1024,  1024,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#252: FILE: drivers/mtd/spi/spi_flash_probe.c:131:
++	{"W25X64",	   0xef3017, 0x0,	 4 * 1024,  2048,	    0,		SECT_4K},
+
+WARNING: line over 80 characters
+#253: FILE: drivers/mtd/spi/spi_flash_probe.c:132:
++	{"W25Q80BL",	   0xef4014, 0x0,	 4 * 1024,   256, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#254: FILE: drivers/mtd/spi/spi_flash_probe.c:133:
++	{"W25Q16CL",	   0xef4015, 0x0,	 4 * 1024,   512, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#255: FILE: drivers/mtd/spi/spi_flash_probe.c:134:
++	{"W25Q32BV",	   0xef4016, 0x0,	 4 * 1024,  1024, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#256: FILE: drivers/mtd/spi/spi_flash_probe.c:135:
++	{"W25Q64CV",	   0xef4017, 0x0,	 4 * 1024,  2048, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#257: FILE: drivers/mtd/spi/spi_flash_probe.c:136:
++	{"W25Q128BV",	   0xef4018, 0x0,	 4 * 1024,  4096, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#258: FILE: drivers/mtd/spi/spi_flash_probe.c:137:
++	{"W25Q256",	   0xef4019, 0x0,	 4 * 1024,  8192, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#259: FILE: drivers/mtd/spi/spi_flash_probe.c:138:
++	{"W25Q80BW",	   0xef5014, 0x0,	 4 * 1024,   256, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#260: FILE: drivers/mtd/spi/spi_flash_probe.c:139:
++	{"W25Q16DW",	   0xef6015, 0x0,	 4 * 1024,   512, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#261: FILE: drivers/mtd/spi/spi_flash_probe.c:140:
++	{"W25Q32DW",	   0xef6016, 0x0,	 4 * 1024,  1024, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#262: FILE: drivers/mtd/spi/spi_flash_probe.c:141:
++	{"W25Q64DW",	   0xef6017, 0x0,	 4 * 1024,  2048, RD_CMD_FULL,		SECT_4K},
+
+WARNING: line over 80 characters
+#263: FILE: drivers/mtd/spi/spi_flash_probe.c:142:
++	{"W25Q128FW",	   0xef6018, 0x0,	 4 * 1024,  4096, RD_CMD_FULL,		SECT_4K},
+
+total: 0 errors, 78 warnings, 0 checks, 313 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0031-sf-Add-extended-read-commands-support.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+WARNING: line over 80 characters
+#98: FILE: drivers/mtd/spi/spi_flash_probe.c:59:
++	{"AT45DB011D",	   0x1f2200, 0x0,	64 * 1024,     4,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#99: FILE: drivers/mtd/spi/spi_flash_probe.c:60:
++	{"AT45DB021D",	   0x1f2300, 0x0,	64 * 1024,     8,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#100: FILE: drivers/mtd/spi/spi_flash_probe.c:61:
++	{"AT45DB041D",	   0x1f2400, 0x0,	64 * 1024,     8,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#101: FILE: drivers/mtd/spi/spi_flash_probe.c:62:
++	{"AT45DB081D",	   0x1f2500, 0x0,	64 * 1024,    16,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#102: FILE: drivers/mtd/spi/spi_flash_probe.c:63:
++	{"AT45DB161D",	   0x1f2600, 0x0,	64 * 1024,    32,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#103: FILE: drivers/mtd/spi/spi_flash_probe.c:64:
++	{"AT45DB321D",	   0x1f2700, 0x0,	64 * 1024,    64,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#104: FILE: drivers/mtd/spi/spi_flash_probe.c:65:
++	{"AT45DB641D",	   0x1f2800, 0x0,	64 * 1024,   128,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#110: FILE: drivers/mtd/spi/spi_flash_probe.c:68:
++	{"EN25Q32B",	   0x1c3016, 0x0,	64 * 1024,    64,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#111: FILE: drivers/mtd/spi/spi_flash_probe.c:69:
++	{"EN25Q64",	   0x1c3017, 0x0,	64 * 1024,   128,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#112: FILE: drivers/mtd/spi/spi_flash_probe.c:70:
++	{"EN25Q128B",	   0x1c3018, 0x0,       64 * 1024,   256,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#117: FILE: drivers/mtd/spi/spi_flash_probe.c:73:
++	{"GD25Q64B",	   0xc84017, 0x0,	64 * 1024,   128,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#118: FILE: drivers/mtd/spi/spi_flash_probe.c:74:
++	{"GD25LQ32",	   0xc86016, 0x0,	64 * 1024,    64,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#128: FILE: drivers/mtd/spi/spi_flash_probe.c:77:
++	{"MX25L4005",	   0xc22013, 0x0,	64 * 1024,     8,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#129: FILE: drivers/mtd/spi/spi_flash_probe.c:78:
++	{"MX25L8005",	   0xc22014, 0x0,	64 * 1024,    16,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#130: FILE: drivers/mtd/spi/spi_flash_probe.c:79:
++	{"MX25L1605D",	   0xc22015, 0x0,	64 * 1024,    32,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#131: FILE: drivers/mtd/spi/spi_flash_probe.c:80:
++	{"MX25L3205D",	   0xc22016, 0x0,	64 * 1024,    64,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#132: FILE: drivers/mtd/spi/spi_flash_probe.c:81:
++	{"MX25L6405D",	   0xc22017, 0x0,	64 * 1024,   128,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#133: FILE: drivers/mtd/spi/spi_flash_probe.c:82:
++	{"MX25L12805",	   0xc22018, 0x0,	64 * 1024,   256,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#134: FILE: drivers/mtd/spi/spi_flash_probe.c:83:
++	{"MX25L12855E",	   0xc22618, 0x0,	64 * 1024,   256,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#148: FILE: drivers/mtd/spi/spi_flash_probe.c:86:
++	{"S25FL008A",	   0x010213, 0x0,	64 * 1024,    16,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#149: FILE: drivers/mtd/spi/spi_flash_probe.c:87:
++	{"S25FL016A",	   0x010214, 0x0,	64 * 1024,    32,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#150: FILE: drivers/mtd/spi/spi_flash_probe.c:88:
++	{"S25FL032A",	   0x010215, 0x0,	64 * 1024,    64,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#151: FILE: drivers/mtd/spi/spi_flash_probe.c:89:
++	{"S25FL064A",	   0x010216, 0x0,	64 * 1024,   128,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#152: FILE: drivers/mtd/spi/spi_flash_probe.c:90:
++	{"S25FL128P_256K", 0x012018, 0x0300,   256 * 1024,    64, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#153: FILE: drivers/mtd/spi/spi_flash_probe.c:91:
++	{"S25FL128P_64K",  0x012018, 0x0301,    64 * 1024,   256, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#154: FILE: drivers/mtd/spi/spi_flash_probe.c:92:
++	{"S25FL032P",	   0x010215, 0x4d00,    64 * 1024,    64, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#155: FILE: drivers/mtd/spi/spi_flash_probe.c:93:
++	{"S25FL064P",	   0x010216, 0x4d00,    64 * 1024,   128, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#156: FILE: drivers/mtd/spi/spi_flash_probe.c:94:
++	{"S25FL128S_64K",  0x012018, 0x4d01,    64 * 1024,   256, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#157: FILE: drivers/mtd/spi/spi_flash_probe.c:95:
++	{"S25FL256S_64K",  0x010219, 0x4d01,    64 * 1024,   512, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#158: FILE: drivers/mtd/spi/spi_flash_probe.c:96:
++	{"S25FL512S_64K",  0x010220, 0x4d01,    64 * 1024,  1024, RD_CMD_FULL, WR_CMD_FULL,		   0},
+
+WARNING: line over 80 characters
+#181: FILE: drivers/mtd/spi/spi_flash_probe.c:99:
++	{"M25P10",	   0x202011, 0x0,       32 * 1024,     4,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#182: FILE: drivers/mtd/spi/spi_flash_probe.c:100:
++	{"M25P20",	   0x202012, 0x0,       64 * 1024,     4,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#183: FILE: drivers/mtd/spi/spi_flash_probe.c:101:
++	{"M25P40",	   0x202013, 0x0,       64 * 1024,     8,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#184: FILE: drivers/mtd/spi/spi_flash_probe.c:102:
++	{"M25P80",	   0x202014, 0x0,       64 * 1024,    16,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#185: FILE: drivers/mtd/spi/spi_flash_probe.c:103:
++	{"M25P16",	   0x202015, 0x0,       64 * 1024,    32,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#186: FILE: drivers/mtd/spi/spi_flash_probe.c:104:
++	{"M25P32",	   0x202016, 0x0,       64 * 1024,    64,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#187: FILE: drivers/mtd/spi/spi_flash_probe.c:105:
++	{"M25P64",	   0x202017, 0x0,       64 * 1024,   128,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#188: FILE: drivers/mtd/spi/spi_flash_probe.c:106:
++	{"M25P128",	   0x202018, 0x0,      256 * 1024,    64,	    0,		 0,		   0},
+
+WARNING: line over 80 characters
+#189: FILE: drivers/mtd/spi/spi_flash_probe.c:107:
++	{"N25Q32",	   0x20ba16, 0x0,       64 * 1024,    64, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#190: FILE: drivers/mtd/spi/spi_flash_probe.c:108:
++	{"N25Q32A",	   0x20bb16, 0x0,       64 * 1024,    64, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#191: FILE: drivers/mtd/spi/spi_flash_probe.c:109:
++	{"N25Q64",	   0x20ba17, 0x0,       64 * 1024,   128, RD_CMD_FULL, WR_CMD_FULL,          SECT_4K},
+
+WARNING: line over 80 characters
+#192: FILE: drivers/mtd/spi/spi_flash_probe.c:110:
++	{"N25Q64A",	   0x20bb17, 0x0,       64 * 1024,   128, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#193: FILE: drivers/mtd/spi/spi_flash_probe.c:111:
++	{"N25Q128",	   0x20ba18, 0x0,       64 * 1024,   256, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#194: FILE: drivers/mtd/spi/spi_flash_probe.c:112:
++	{"N25Q128A",	   0x20bb18, 0x0,       64 * 1024,   256, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#195: FILE: drivers/mtd/spi/spi_flash_probe.c:113:
++	{"N25Q256",	   0x20ba19, 0x0,       64 * 1024,   512, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#196: FILE: drivers/mtd/spi/spi_flash_probe.c:114:
++	{"N25Q256A",	   0x20bb19, 0x0,       64 * 1024,   512, RD_CMD_FULL, WR_CMD_FULL,	     SECT_4K},
+
+WARNING: line over 80 characters
+#197: FILE: drivers/mtd/spi/spi_flash_probe.c:115:
++	{"N25Q512",	   0x20ba20, 0x0,       64 * 1024,  1024, RD_CMD_FULL, WR_CMD_FULL,  E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#198: FILE: drivers/mtd/spi/spi_flash_probe.c:116:
++	{"N25Q512A",	   0x20bb20, 0x0,       64 * 1024,  1024, RD_CMD_FULL, WR_CMD_FULL,  E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#199: FILE: drivers/mtd/spi/spi_flash_probe.c:117:
++	{"N25Q1024",	   0x20ba21, 0x0,       64 * 1024,  2048, RD_CMD_FULL, WR_CMD_FULL,  E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#200: FILE: drivers/mtd/spi/spi_flash_probe.c:118:
++	{"N25Q1024A",	   0x20bb21, 0x0,       64 * 1024,  2048, RD_CMD_FULL, WR_CMD_FULL,  E_FSR | SECT_4K},
+
+WARNING: line over 80 characters
+#213: FILE: drivers/mtd/spi/spi_flash_probe.c:121:
++	{"SST25VF040B",	   0xbf258d, 0x0,	64 * 1024,     8,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#214: FILE: drivers/mtd/spi/spi_flash_probe.c:122:
++	{"SST25VF080B",	   0xbf258e, 0x0,	64 * 1024,    16,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#215: FILE: drivers/mtd/spi/spi_flash_probe.c:123:
++	{"SST25VF016B",	   0xbf2541, 0x0,	64 * 1024,    32,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#216: FILE: drivers/mtd/spi/spi_flash_probe.c:124:
++	{"SST25VF032B",	   0xbf254a, 0x0,	64 * 1024,    64,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#217: FILE: drivers/mtd/spi/spi_flash_probe.c:125:
++	{"SST25VF064C",	   0xbf254b, 0x0,	64 * 1024,   128,	    0,		 0,	     SECT_4K},
+
+WARNING: line over 80 characters
+#218: FILE: drivers/mtd/spi/spi_flash_probe.c:126:
++	{"SST25WF512",	   0xbf2501, 0x0,	64 * 1024,     1,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#219: FILE: drivers/mtd/spi/spi_flash_probe.c:127:
++	{"SST25WF010",	   0xbf2502, 0x0,	64 * 1024,     2,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#220: FILE: drivers/mtd/spi/spi_flash_probe.c:128:
++	{"SST25WF020",	   0xbf2503, 0x0,	64 * 1024,     4,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#221: FILE: drivers/mtd/spi/spi_flash_probe.c:129:
++	{"SST25WF040",	   0xbf2504, 0x0,	64 * 1024,     8,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#222: FILE: drivers/mtd/spi/spi_flash_probe.c:130:
++	{"SST25WF080",	   0xbf2505, 0x0,	64 * 1024,    16,	    0,		 0, SECT_4K | SST_WP},
+
+WARNING: line over 80 characters
+#243: FILE: drivers/mtd/spi/spi_flash_probe.c:133:
++	{"W25P80",	   0xef2014, 0x0,	64 * 1024,    16,	    0,		 0,		  0},
+
+WARNING: line over 80 characters
+#244: FILE: drivers/mtd/spi/spi_flash_probe.c:134:
++	{"W25P16",	   0xef2015, 0x0,	64 * 1024,    32,	    0,		 0,		  0},
+
+WARNING: line over 80 characters
+#245: FILE: drivers/mtd/spi/spi_flash_probe.c:135:
++	{"W25P32",	   0xef2016, 0x0,	64 * 1024,    64,	    0,		 0,		  0},
+
+WARNING: line over 80 characters
+#246: FILE: drivers/mtd/spi/spi_flash_probe.c:136:
++	{"W25X40",	   0xef3013, 0x0,	 4 * 1024,   128,	    0,		 0,	    SECT_4K},
+
+WARNING: line over 80 characters
+#247: FILE: drivers/mtd/spi/spi_flash_probe.c:137:
++	{"W25X16",	   0xef3015, 0x0,	 4 * 1024,   512,	    0,		 0,	    SECT_4K},
+
+WARNING: line over 80 characters
+#248: FILE: drivers/mtd/spi/spi_flash_probe.c:138:
++	{"W25X32",	   0xef3016, 0x0,	 4 * 1024,  1024,	    0,		 0,	    SECT_4K},
+
+WARNING: line over 80 characters
+#249: FILE: drivers/mtd/spi/spi_flash_probe.c:139:
++	{"W25X64",	   0xef3017, 0x0,	 4 * 1024,  2048,	    0,		 0,	    SECT_4K},
+
+WARNING: line over 80 characters
+#250: FILE: drivers/mtd/spi/spi_flash_probe.c:140:
++	{"W25Q80BL",	   0xef4014, 0x0,	 4 * 1024,   256, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#251: FILE: drivers/mtd/spi/spi_flash_probe.c:141:
++	{"W25Q16CL",	   0xef4015, 0x0,	 4 * 1024,   512, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#252: FILE: drivers/mtd/spi/spi_flash_probe.c:142:
++	{"W25Q32BV",	   0xef4016, 0x0,	 4 * 1024,  1024, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#253: FILE: drivers/mtd/spi/spi_flash_probe.c:143:
++	{"W25Q64CV",	   0xef4017, 0x0,	 4 * 1024,  2048, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#254: FILE: drivers/mtd/spi/spi_flash_probe.c:144:
++	{"W25Q128BV",	   0xef4018, 0x0,	 4 * 1024,  4096, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#255: FILE: drivers/mtd/spi/spi_flash_probe.c:145:
++	{"W25Q256",	   0xef4019, 0x0,	 4 * 1024,  8192, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#256: FILE: drivers/mtd/spi/spi_flash_probe.c:146:
++	{"W25Q80BW",	   0xef5014, 0x0,	 4 * 1024,   256, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#257: FILE: drivers/mtd/spi/spi_flash_probe.c:147:
++	{"W25Q16DW",	   0xef6015, 0x0,	 4 * 1024,   512, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#258: FILE: drivers/mtd/spi/spi_flash_probe.c:148:
++	{"W25Q32DW",	   0xef6016, 0x0,	 4 * 1024,  1024, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#259: FILE: drivers/mtd/spi/spi_flash_probe.c:149:
++	{"W25Q64DW",	   0xef6017, 0x0,	 4 * 1024,  2048, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+WARNING: line over 80 characters
+#260: FILE: drivers/mtd/spi/spi_flash_probe.c:150:
++	{"W25Q128FW",	   0xef6018, 0x0,	 4 * 1024,  4096, RD_CMD_FULL, WR_CMD_FULL,	    SECT_4K},
+
+total: 0 errors, 78 warnings, 0 checks, 311 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0032-sf-Add-quad-read-write-commands-support.patch has style problems, please review.
+
+If any of these errors are false positives, please report
+them to the maintainer, see CHECKPATCH in MAINTAINERS.
+total: 0 errors, 0 warnings, 0 checks, 30 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0033-sf-ops-Add-configuration-register-writing-support.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 68 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0034-sf-Set-quad-enable-bit-support.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 332 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0035-sf-spi_flash-cleanups.patch has no obvious style problems and is ready for submission.
+total: 0 errors, 0 warnings, 0 checks, 212 lines checked
+
+NOTE: Ignored message types: COMPLEX_MACRO CONSIDER_KSTRTO MINMAX MULTISTATEMENT_MACRO_USE_DO_WHILE NETWORKING_BLOCK_COMMENT_STYLE USLEEP_RANGE
+
+0036-spi-spi-cleanups.patch has no obvious style problems and is ready for submission.
diff --git a/drivers/mtd/spi/spi_flash_probe.c b/drivers/mtd/spi/spi_flash_probe.c
index a8ce358..283e3ea 100644
--- a/drivers/mtd/spi/spi_flash_probe.c
+++ b/drivers/mtd/spi/spi_flash_probe.c
@@ -53,6 +53,19 @@ static const struct spi_flash_params spi_flash_params_table[] = {
 	{"MX25L12805",		0xc22018, 0x0,	   64 * 1024,	 256},
 	{"MX25L12855E",		0xc22618, 0x0,	   64 * 1024,	 256},
 #endif
+#ifdef CONFIG_SPI_FLASH_SPANSION	/* SPANSION */
+	{"S25FL008A",		0x010213, 0x0,	   64 * 1024,	  16},
+	{"S25FL016A",		0x010214, 0x0,	   64 * 1024,	  32},
+	{"S25FL032A",		0x010215, 0x0,	   64 * 1024,	  64},
+	{"S25FL064A",		0x010216, 0x0,	   64 * 1024,	 128},
+	{"S25FL128P_256K",	0x012018, 0x0300, 256 * 1024,	  64},
+	{"S25FL128P_64K",	0x012018, 0x0301,  64 * 1024,	 256},
+	{"S25FL032P",		0x010215, 0x4d00,  64 * 1024,	  64},
+	{"S25FL064P",		0x010216, 0x4d00,  64 * 1024,	 128},
+	{"S25FL128S_64K",	0x012018, 0x4d01,  64 * 1024,	 256},
+	{"S25FL256S_64K",	0x010219, 0x4d01,  64 * 1024,	 512},
+	{"S25FL512S_64K",	0x010220, 0x4d01,  64 * 1024,	1024},
+#endif
 #ifdef CONFIG_SPI_FLASH_STMICRO		/* STMICRO */
 	{"M25P10",		0x202011, 0x0,     32 * 1024,	   4},
 	{"M25P20",		0x202012, 0x0,     64 * 1024,	   4},
@@ -98,6 +111,7 @@ static const struct spi_flash_params spi_flash_params_table[] = {
 	/*
 	 * Note:
 	 * Below paired flash devices has similar spi_flash_params params.
+	 * (S25FL129P_64K, S25FL128S_64K)
 	 * (W25Q80BL, W25Q80BV)
 	 * (W25Q16CL, W25Q16DV)
 	 * (W25Q32BV, W25Q32FV_SPI)
@@ -111,7 +125,6 @@ static const struct spi_flash_params spi_flash_params_table[] = {
 	 * TODO:
 	 * ATMEL
 	 * RAMTRON
-	 * SPANSION
 	 * SST
 	 */
 };
@@ -122,19 +135,25 @@ struct spi_flash *spi_flash_validate_ids(struct spi_slave *spi, u8 *idcode)
 	struct spi_flash *flash;
 	int i;
 	u16 jedec = idcode[1] << 8 | idcode[2];
+	u16 ext_jedec = idcode[3] << 8 | idcode[4];
 
 	/* Get the flash id (jedec = manuf_id + dev_id) */
 	for (i = 0; i < ARRAY_SIZE(spi_flash_params_table); i++) {
 		params = &spi_flash_params_table[i];
 		if ((params->jedec >> 16) == idcode[0]) {
-			if ((params->jedec & 0xFFFF) == jedec)
-				break;
+			if ((params->jedec & 0xFFFF) == jedec) {
+				if (params->ext_jedec == 0)
+					break;
+				else if (params->ext_jedec == ext_jedec)
+					break;
+			}
 		}
 	}
 
 	if (i == ARRAY_SIZE(spi_flash_params_table)) {
-		printf("SF: Unsupported flash ID: manuf %02x, jedec %04x\n",
-		       idcode[0], jedec);
+		printf("SF: Unsupported flash IDs: ");
+		printf("manuf %02x, jedec %04x, ext_jedec %04x\n",
+		       idcode[0], jedec, ext_jedec);
 		return NULL;
 	}
 
@@ -122,19 +135,25 @@ struct spi_flash *spi_flash_validate_ids(struct spi_slave *spi, u8 *idcode)
 
-	/* Get the flash id (jedec = manuf_id + dev_id) */
+	/* Get the flash id (jedec = manuf_id + dev_id, ext_jedec) */
 	for (i = 0; i < ARRAY_SIZE(spi_flash_params_table); i++) {
 		params = &spi_flash_params_table[i];
-- 
1.8.3




More information about the U-Boot mailing list